@@ -58,8 +58,8 @@ struct StopTime {
     precision: Option<StopTimePrecision>,
 }
 
-#[derivative(Default)]
 #[derive(Derivative, Serialize, Deserialize, Debug, Clone, PartialEq)]
+#[derivative(Default)]
 enum StopLocationType {
     #[derivative(Default)]
     #[serde(rename = "0")]
@@ -176,14 +176,14 @@ fn has_fares_v1(collections: &Collections) -> bool {
 /// Imports a `Model` from the
 /// [NTFS](https://github.com/CanalTP/ntfs-specification/blob/master/ntfs_fr.md)
 /// files in the given directory.
-pub fn read_from_path<P: AsRef<path::Path>>(p: P) -> Result<Model> {
+pub fn from_dir<P: AsRef<path::Path>>(p: P) -> Result<Model> {
     let mut file_handle = read_utils::PathFileHandler::new(p.as_ref().to_path_buf());
     read_file_handler(&mut file_handle)
 }
 
 /// Imports a `Model` from a zip file containing the
 /// [NTFS](https://github.com/CanalTP/ntfs-specification/blob/master/ntfs_fr.md).
-pub fn read_from_zip<P: AsRef<path::Path>>(p: P) -> Result<Model> {
+pub fn from_zip<P: AsRef<path::Path>>(p: P) -> Result<Model> {
     let reader = std::fs::File::open(p.as_ref())?;
     let mut file_handler = read_utils::ZipHandler::new(reader, p)?;
     read_file_handler(&mut file_handler)
@@ -195,15 +195,16 @@ pub fn read_from_zip<P: AsRef<path::Path>>(p: P) -> Result<Model> {
 /// This method makes it possible to read from a variety of sources like read a NTFS
 /// from the network.
 ///
-/// ```
-// let url = "http://some_url/ntfs.zip";
-// let resp = reqwest::blocking::get(url)?; // or async call
-// let data = std::io::Cursor::new(resp.bytes()?.to_vec());
-// let model = transit_model::ntfs::from_read(data, &url)?;
+/// ```ignore
+/// let url = "http://some_url/ntfs.zip";
+/// let resp = reqwest::blocking::get(url)?; // or async call
+/// let data = std::io::Cursor::new(resp.bytes()?.to_vec());
+/// let model = transit_model::ntfs::from_zip_reader(data, &url)?;
+/// # Ok::<(), transit_model::Error>(())
 /// ```
 ///
 /// The `source_name` is needed to have nicer error messages.
-pub fn from_read<R>(reader: R, source_name: &str) -> Result<Model>
+pub fn from_zip_reader<R>(reader: R, source_name: &str) -> Result<Model>
 where
     R: std::io::Seek + std::io::Read,
 {
@@ -214,16 +215,16 @@ where
 /// Imports a `Model` from the
 /// [NTFS](https://github.com/CanalTP/ntfs-specification/blob/master/ntfs_fr.md)
 /// files in the given directory.
-/// This method will try to detect if the input is a ziped archive or not.
+/// This method will try to detect if the input is a zipped archive or not.
 /// If the default file type mechanism is not enough, you can use
-/// [read_from_zip] or [read_from_path].
+/// [from_zip] or [from_dir].
 pub fn read<P: AsRef<path::Path>>(path: P) -> Result<Model> {
     let p = path.as_ref();
     if p.is_file() {
         // if it's a file, we consider it to be a zip (and an error will be returned if it is not)
-        Ok(read_from_zip(p).with_context(|_| format!("impossible to read ziped ntfs {:?}", p))?)
+        Ok(from_zip(p).with_context(|_| format!("impossible to read zipped ntfs {:?}", p))?)
     } else if p.is_dir() {
-        Ok(read_from_path(p)
+        Ok(from_dir(p)
             .with_context(|_| format!("impossible to read ntfs directory from {:?}", p))?)
     } else {
         Err(failure::format_err!(
@@ -547,7 +548,7 @@ mod tests {
                 name: "DEF".to_string(),
                 code: Some("DEF".to_string()),
                 codes: KeysValues::default(),
-                object_properties: KeysValues::default(),
+                object_properties: PropertiesMap::default(),
                 comment_links: CommentLinksT::default(),
                 forward_name: Some("Hôtels - Hôtels".to_string()),
                 forward_direction: None,
@@ -575,7 +576,7 @@ mod tests {
                 name: "3".to_string(),
                 code: None,
                 codes: KeysValues::default(),
-                object_properties: KeysValues::default(),
+                object_properties: PropertiesMap::default(),
                 comment_links: CommentLinksT::default(),
                 forward_name: None,
                 forward_direction: None,
@@ -622,7 +623,7 @@ mod tests {
                 name: "Hôtels - Hôtels".to_string(),
                 direction_type: Some("forward".to_string()),
                 codes: KeysValues::default(),
-                object_properties: KeysValues::default(),
+                object_properties: PropertiesMap::default(),
                 comment_links: CommentLinksT::default(),
                 line_id: "OIF:002002002:BDEOIF829".to_string(),
                 geometry_id: Some("Geometry:Line:Relation:6883353".to_string()),
@@ -633,7 +634,7 @@ mod tests {
                 name: "Hôtels - Hôtels".to_string(),
                 direction_type: None,
                 codes: KeysValues::default(),
-                object_properties: KeysValues::default(),
+                object_properties: PropertiesMap::default(),
                 comment_links: CommentLinksT::default(),
                 line_id: "OIF:002002002:BDEOIF829".to_string(),
                 geometry_id: None,
@@ -678,7 +679,7 @@ mod tests {
             VehicleJourney {
                 id: "OIF:87604986-1_11595-1".to_string(),
                 codes: KeysValues::default(),
-                object_properties: KeysValues::default(),
+                object_properties: PropertiesMap::default(),
                 comment_links: CommentLinksT::default(),
                 route_id: "OIF:078078001:1".to_string(),
                 physical_mode_id: "Bus".to_string(),
@@ -723,7 +724,7 @@ mod tests {
             VehicleJourney {
                 id: "OIF:90014407-1_425283-1".to_string(),
                 codes: KeysValues::default(),
-                object_properties: KeysValues::default(),
+                object_properties: PropertiesMap::default(),
                 comment_links: CommentLinksT::default(),
                 route_id: "OIF:800:TER".to_string(),
                 physical_mode_id: "Bus".to_string(),
@@ -953,7 +954,7 @@ mod tests {
                 id: "Navitia:sa_2".to_string(),
                 name: "sa_name_2".to_string(),
                 codes: KeysValues::default(),
-                object_properties: KeysValues::default(),
+                object_properties: PropertiesMap::default(),
                 comment_links: CommentLinksT::default(),
                 visible: true,
                 coord: Coord {
@@ -969,7 +970,7 @@ mod tests {
                 id: "sa_1".to_string(),
                 name: "sa_name_1".to_string(),
                 codes: KeysValues::default(),
-                object_properties: KeysValues::default(),
+                object_properties: PropertiesMap::default(),
                 comment_links: CommentLinksT::default(),
                 visible: true,
                 coord: Coord {
@@ -1033,10 +1034,10 @@ mod tests {
                 "object_system:1".to_string(),
                 "object_code:1".to_string(),
             )]),
-            object_properties: btree_set_from_vec(vec![(
+            object_properties: properties_map![(
                 "prop_name:1".to_string(),
-                "prop_value:1".to_string(),
-            )]),
+                "prop_value:1".to_string()
+            )],
             comment_links: btree_set_from_vec(vec!["c:1".to_string()]),
             visible: true,
             coord: Coord {
@@ -1055,10 +1056,10 @@ mod tests {
                 "object_system:2".to_string(),
                 "object_code:2".to_string(),
             )]),
-            object_properties: btree_set_from_vec(vec![(
+            object_properties: properties_map![(
                 "prop_name:2".to_string(),
-                "prop_value:2".to_string(),
-            )]),
+                "prop_value:2".to_string()
+            )],
             comment_links: btree_set_from_vec(vec!["c:2".to_string()]),
             visible: true,
             coord: Coord {
@@ -1081,10 +1082,10 @@ mod tests {
                 "object_system:3".to_string(),
                 "object_code:3".to_string(),
             )]),
-            object_properties: btree_set_from_vec(vec![(
+            object_properties: properties_map![(
                 "prop_name:3".to_string(),
-                "prop_value:3".to_string(),
-            )]),
+                "prop_value:3".to_string()
+            )],
             comment_links: btree_set_from_vec(vec!["c:1".to_string(), "c:2".to_string()]),
             forward_name: None,
             forward_direction: None,
@@ -1108,10 +1109,10 @@ mod tests {
                 ("object_system:4".to_string(), "object_code:4".to_string()),
                 ("object_system:5".to_string(), "object_code:5".to_string()),
             ]),
-            object_properties: btree_set_from_vec(vec![(
+            object_properties: properties_map![(
                 "prop_name:4".to_string(),
-                "prop_value:4".to_string(),
-            )]),
+                "prop_value:4".to_string()
+            )],
             comment_links: btree_set_from_vec(vec!["c:3".to_string()]),
             line_id: "OIF:002002002:BDEOIF829".to_string(),
             geometry_id: None,
@@ -1124,10 +1125,10 @@ mod tests {
                 "object_system:6".to_string(),
                 "object_code:6".to_string(),
             )]),
-            object_properties: btree_set_from_vec(vec![(
+            object_properties: properties_map![(
                 "prop_name:6".to_string(),
-                "prop_value:6".to_string(),
-            )]),
+                "prop_value:6".to_string()
+            )],
             comment_links: CommentLinksT::default(),
             route_id: "OIF:800:TER".to_string(),
             physical_mode_id: "Bus".to_string(),
