@@ -121,7 +121,7 @@ pub type CommentLinksT = BTreeSet<String>;
 
 impl AddPrefix for CommentLinksT {
     fn prefix(&mut self, prefix_conf: &PrefixConfiguration) {
-        let updated_ids = std::mem::replace(self, BTreeSet::new());
+        let updated_ids = std::mem::take(self);
         *self = updated_ids
             .into_iter()
             .map(|comment_id| prefix_conf.schedule_prefix(comment_id.as_str()))
@@ -996,6 +996,21 @@ impl From<GeoPoint<f64>> for Coord {
     }
 }
 
+#[cfg(feature = "proj")]
+impl proj::Coord<f64> for Coord {
+    fn x(&self) -> f64 {
+        self.lon
+    }
+
+    fn y(&self) -> f64 {
+        self.lat
+    }
+
+    fn from_xy(x: f64, y: f64) -> Self {
+        Self { lon: x, lat: y }
+    }
+}
+
 impl Coord {
     /// Calculate the orthodromic distance in meters
     /// between 2 geographic coordinates
