@@ -17,15 +17,16 @@ use crate::{
     read_utils::{read_objects, FileHandler},
 };
 use chrono::NaiveDate;
-use failure::{format_err, ResultExt};
-use log::{debug, error, info};
+use failure::ResultExt;
+use log::{debug, error, info, Level as LogLevel};
 use rust_decimal::Decimal;
+use skip_error::skip_error_and_log;
 use std::fs;
 use std::io::{Read, Write};
 use std::path;
 use typed_index_collection::{Collection, CollectionWithId, Id};
 use walkdir::WalkDir;
-use wkt::{self, conversion::try_into_geometry, ToWkt};
+use wkt::ToWkt;
 
 pub fn zip_to<P, R>(source_path: P, zip_file: R) -> crate::Result<()>
 where
@@ -174,7 +175,8 @@ where
     use serde::Deserialize;
     let s = String::deserialize(deserializer)?;
     let wkt = wkt::Wkt::from_str(&s).map_err(serde::de::Error::custom)?;
-    try_into_geometry(&wkt.items[0]).map_err(serde::de::Error::custom)
+    use std::convert::TryInto;
+    wkt.try_into().map_err(serde::de::Error::custom)
 }
 
 pub fn de_positive_decimal<'de, D>(deserializer: D) -> Result<Decimal, D::Error>
@@ -303,8 +305,11 @@ where
     for<'de> T: Id<T> + serde::Deserialize<'de>,
     for<'a> &'a mut H: FileHandler,
 {
-    let vec = read_objects::<_, T>(file_handler, file, false)?;
-    CollectionWithId::new(vec).map_err(|e| format_err!("{}", e))
+    let mut collection = CollectionWithId::<T>::default();
+    for object in read_objects::<_, T>(file_handler, file, false)? {
+        skip_error_and_log!(collection.push(object), LogLevel::Warn);
+    }
+    Ok(collection)
 }
 
 pub(crate) fn make_collection_with_id<T, H>(
@@ -315,8 +320,11 @@ where
     for<'de> T: Id<T> + serde::Deserialize<'de>,
     for<'a> &'a mut H: FileHandler,
 {
-    let vec = read_objects::<_, T>(file_handler, file, true)?;
-    CollectionWithId::new(vec).map_err(|e| format_err!("{}", e))
+    let mut collection = CollectionWithId::<T>::default();
+    for object in read_objects::<_, T>(file_handler, file, true)? {
+        skip_error_and_log!(collection.push(object), LogLevel::Warn);
+    }
+    Ok(collection)
 }
 
 pub(crate) fn make_opt_collection<T, H>(
